From: Linus Torvalds Date: Sat, 21 May 2005 01:44:30 GMT Subject: Re: checkout-cache -f: a better way? Message-ID: In-Reply-To: <428E7994.1090402@pobox.com> On Fri, 20 May 2005, Jeff Garzik wrote: > > Yep, thanks. Script does seem faster now. Yeah. They "seem faster". > real 0m7.069s to > real 0m0.389s That's what, 20 times faster? More, actually, I suspect, since the "-m" version is not only faster, but it doesn't do much IO, so you'll not have tons of dirty pages/inodes etc afterwards. Linus